ska.contrib.django.ska.integration.drf.urls package
===================================================

Submodules
----------

ska.contrib.django.ska.integration.drf.urls.jwt\_token module
-------------------------------------------------------------

.. automodule:: ska.contrib.django.ska.integration.drf.urls.jwt_token
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: ska.contrib.django.ska.integration.drf.urls
    :members:
    :undoc-members:
    :show-inheritance:
